Threshold
=========

.. automodule:: icclim.generic_indices.threshold
    :members:

    .. rubric:: Functions

    .. autosummary::

        build_threshold

    .. rubric:: Classes

    .. autosummary::
        Threshold
        BasicThreshold
        PercentileThreshold
        BoundedThreshold
